@@ -433,6 +433,17 @@ authselect_files_smartcardauth(const struct authselect_files *files);
 const char *
 authselect_files_fingerprintauth(const struct authselect_files *files);
 
+/**
+ * Get switchable-auth pam stack content.
+ *
+ * @param files    Pointer to structure obtained by @authselect_cat.
+ *
+ * @return Generated switchable-auth pam stack content or NULL if the profile does
+ * not touch this stack.
+ */
+const char *
+authselect_files_switchableauth(const struct authselect_files *files);
+
 /**
  * Get postlogin pam stack content.
  *
@@ -502,6 +513,12 @@ authselect_path_smartcardauth();
 const char *
 authselect_path_fingerprintauth();
 
+/**
+ * @return Path to system switchable-auth pam stack.
+ */
+const char *
+authselect_path_switchableauth();
+
 /**
  * @return Path to system postlogin pam stack.
  */
