@@ -559,6 +559,7 @@ static errno_t test(struct cli_cmdline *cmdline)
     int print_passwordauth = 0;
     int print_smartcardauth = 0;
     int print_fingerprintauth = 0;
+    int print_switchableauth = 0;
     int print_postlogin = 0;
     int print_dconfdb = 0;
     int print_dconflock = 0;
@@ -572,6 +573,7 @@ static errno_t test(struct cli_cmdline *cmdline)
         {"password-auth", 'p', POPT_ARG_VAL, &print_passwordauth, 1, _("Print password-auth content"), NULL },
         {"smartcard-auth", 'c', POPT_ARG_VAL, &print_smartcardauth, 1, _("Print smartcard-auth content"), NULL },
         {"fingerprint-auth", 'f', POPT_ARG_VAL, &print_fingerprintauth, 1, _("Print fingerprint-auth content"), NULL },
+        {"switchable-auth", 'w', POPT_ARG_VAL, &print_switchableauth, 1, _("Print switchable-auth content"), NULL },
         {"postlogin", 'o', POPT_ARG_VAL, &print_postlogin, 1, _("Print postlogin content"), NULL },
         {"dconf-db", 'd', POPT_ARG_VAL, &print_dconfdb, 1, _("Print dconf database content"), NULL },
         {"dconf-lock", 'l', POPT_ARG_VAL, &print_dconflock, 1, _("Print dconf lock content"), NULL },
@@ -588,6 +590,7 @@ static errno_t test(struct cli_cmdline *cmdline)
         {authselect_files_passwordauth, authselect_path_passwordauth, &print_passwordauth},
         {authselect_files_smartcardauth, authselect_path_smartcardauth, &print_smartcardauth},
         {authselect_files_fingerprintauth, authselect_path_fingerprintauth, &print_fingerprintauth},
+        {authselect_files_switchableauth, authselect_path_switchableauth, &print_switchableauth},
         {authselect_files_postlogin, authselect_path_postlogin, &print_postlogin},
         {authselect_files_dconf_db, authselect_path_dconf_db, &print_dconfdb},
         {authselect_files_dconf_lock, authselect_path_dconf_lock, &print_dconflock},
